@@ -99,7 +99,8 @@ class FormForForm(forms.ModelForm):
             css_class = field_class.__name__.lower()
             if field.required:
                 css_class += " required"
-                if settings.FORMS_USE_HTML5:
+                if (settings.FORMS_USE_HTML5 and
+                    field.field_type != fields.CHECKBOX_MULTIPLE):
                     self.fields[field_key].widget.attrs["required"] = ""
             self.fields[field_key].widget.attrs["class"] = css_class
             if field.placeholder_text and not field.default:
